@@ -89,6 +89,7 @@ class MyStromBulb(object):
         self.data = None
         self.state = None
         self.consumption = 0
+        self.brightness = 0
         self.color = None
         self.transition_time = 0
 
@@ -125,6 +126,16 @@ class MyStromBulb(object):
 
         return self.consumption
 
+    def get_brightness(self):
+        """Get current brightness."""
+        self.get_status()
+        try:
+            self.brightness = self.data['color'].split(';')[-1]
+        except TypeError:
+            self.brightness = 0
+
+        return self.brightness
+
     def get_transition_time(self):
         """Get the transition time in ms."""
         self.get_status()
@@ -147,6 +158,20 @@ class MyStromBulb(object):
 
         return {'color': self.color, 'mode': self.mode}
 
+    def set_on(self):
+        """Turn the bulb on with the previous used settings."""
+        try:
+            request = requests.post(
+                '{}/{}/{}/'.format(self.resource, URI, self._mac),
+                data={
+                    'action': 'on',
+                },
+                timeout=self.timeout)
+            if request.status_code == 200:
+                pass
+        except requests.exceptions.ConnectionError:
+            raise exceptions.MyStromConnectionError()
+
     def set_color_hex(self, value):
         """Turn the bulb on with the given color as HEX.
 
@@ -160,7 +185,6 @@ class MyStromBulb(object):
                 '{}/{}/{}/'.format(self.resource, URI, self._mac),
                 data={
                     'action': 'on',
-                    'mode': 'rgb',
                     'color': value,
                 },
                 timeout=self.timeout)
@@ -177,7 +201,7 @@ class MyStromBulb(object):
             import subprocess
             subprocess.run(
                 [
-                    'curl', '-d', 'action=on', '-d', 'mode=hsv', '-d',
+                    'curl', '-d', 'action=on', '-d',
                     'color={};{};{}'.format(hue, saturation, value),
                     '{}/{}/{}'.format(self.resource, URI, self._mac),
                  ],
@@ -186,7 +210,6 @@ class MyStromBulb(object):
             #     '{}/{}/{}'.format(self.resource, URI, self._mac),
             #     data={
             #         'action': 'on',
-            #         'mode': 'hsv',
             #         'color': '{};{};{}'.format(hue, saturation, value),
             #     },
             #     timeout=self.timeout)
@@ -200,21 +223,20 @@ class MyStromBulb(object):
         self.set_color_hex('FF000000')
 
     def set_rainbow(self, duration):
-        """Turn the bulb on, create a rainbow."""
-        self.set_transition_time(100)
+        """Turn the bulb on and create a rainbow."""
         for i in range(0, 359):
             self.set_color_hsv(i, 100, 100)
             time.sleep(duration/359)
 
     def set_sunrise(self, duration):
-        """Turn the bulb on, full white."""
+        """Turn the bulb on and create a sunrise."""
         self.set_transition_time(duration/100)
         for i in range(0, duration):
             try:
                 import subprocess
                 subprocess.run(
                     [
-                        'curl', '-d', 'action=on', '-d', 'mode=mono', '-d',
+                        'curl', '-d', 'action=on', '-d',
                         'color=3;{}'.format(i),
                         '{}/{}/{}'.format(self.resource, URI, self._mac),
                      ],
@@ -224,7 +246,7 @@ class MyStromBulb(object):
             time.sleep(duration/100)
 
     def set_flashing(self, duration, color1, color2):
-        """Turn the bulb on, full white."""
+        """Turn the bulb on, flashing with two colors."""
         self.set_transition_time(100)
         for i in range(0, int(duration/2)):
             self.set_color_hex(color1)
